@@ -14,10 +14,12 @@ async def reliably_client() -> httpx.AsyncClient:
     org_id = settings.organization.id
     token = settings.agent.token
 
+    headers = {"Authorization": f"Bearer {token.get_secret_value()}"}
+
     async with httpx.AsyncClient(
         http2=True,
         base_url=f"{host}/api/v1/organization/{org_id}",
-        headers={"Authorization": f"Bearer {token.get_secret_value()}"},
+        headers=headers,
         timeout=30.0,
     ) as c:
         yield c
